Learn R Programming

GPoM.FDLyapu (version 1.0)

Reit98: The 9D model for a Rayleigh-B<U+00E9>nard convection in a square cell

Description

The 9D model for a Rayleigh-B<U+00E9>nard convection in a square cell was introduced by Reiterer et al. in 1998. It can produce an apparently smooth transition from chaos to hyperchaos.

Usage

Reit98

Arguments

Format

An object of class matrix with 55 rows and 9 columns.

References

P. Reiterer, C. Lainscsek, F. Sch<U+00FC>rrer, C. Letellier, and J. Maquet, A nine-dimensional Lorenz system to study high-dimensional chaos, Journal of Physics A, 31, 7121-7139, 1998.