Learn R Programming

GPoM.FDLyapu (version 1.0)

lyapFDWolf: lyapFDWolf : computes Lyapunov spectrum with Wolf method

Description

Computes all the Lyapunov exponents based on Gram-Schmidt procedure (Wolf et al. 1985). The Jacobian matrix is computed from the original model by semi-Formal Derivation.

Usage

lyapFDWolf(outLyapFD = NULL, nVar, dMax, coeffF, intgrMthod = "rk4",
  tDeb = 0, dt, tFin, yDeb, Ddeb = NULL, nIterMin = 1,
  nIterStats = 50)

Arguments

outLyapFD

List of output data that can be used as an input in order to extend the computation

nVar

Model dimension

dMax

Maximum degree of the polynomial formulation

coeffF

Model matrix. Each column correspond to one equation. Lines provide the coefficients for each polynomial term which order is defined with function poLabs(nVar, dMax) in package GPoM)

intgrMthod

Numerical integration method ('rk4' by default)

tDeb

Initial integration time (0 by default)

dt

Integration time step

tFin

Final integration time

yDeb

Model initial conditions

Ddeb

Jacobian initial conditions (optional).

nIterMin

Minimum number of iterations (nIterMin= 1 by default)

nIterStats

Number of iterations used in the statistics computation

Value

List of output data

References

A. Wolf, J. B. Swift, H. L. Swinney & J. A. Vastano, Determining Lyapunov exponents from a time series, Physica D, 285-317, 1985.

Examples

Run this code
# NOT RUN {
data(Ebola)
nVar = dim(Ebola$KL)[2]
pMax = dim(Ebola$KL)[1]
dMax = p2dMax(nVar, pMax)
outLyapFD <- NULL
outLyapFD$Wolf <- lyapFDWolf(outLyapFD$Wolf, nVar= nVar, dMax = dMax,
                             coeffF = Ebola$KL,
                             tDeb = 0, dt = 0.01, tFin = 2,
                             yDeb = Ebola$yDeb)

# }

Run the code above in your browser using DataLab