The eco-epidemiolgy plague model is a three-dimensional model obtained using the global modelling technique from a set of three observational variables: - X the number of human cases - Y the number of contaminated brown rats - Z the number of contaminated black rats \(dX/dt = fx(X,Y,Z)\) \(dY/dt = fy(X,Y,Z)\) \(dZ/dt = fz(X,Y,Z)\). It can produce a chaotic behavior by tuning its parameterization. Its formulation can be visualized using visuEq(K = GP_DRDT_1110_dM2$models$model93, approx = 2, substit = 1) (the number of digit is truncated)
PlagueAn object of class list of length 1.
[1] Sylvain Mangiarotti, Low dimensional chaotic models for the plague epidemic in Bombay (1896-1911), Chaos Solitons \& Fractals, 26, 113112, 2016.